@@ -59,6 +59,10 @@ class CreateSessionRequest(AbstractModel):
         :type Role: str
         :param GameContext: 游戏相关参数
         :type GameContext: str
+        :param RunMode: 云端运行模式。
+RunWithoutClient：允许无客户端连接的情况下仍保持云端 App 运行
+默认值（空）：要求必须有客户端连接才会保持云端 App 运行。
+        :type RunMode: str
         """
         self.ClientSession = None
         self.UserId = None
@@ -77,6 +81,7 @@ class CreateSessionRequest(AbstractModel):
         self.HostUserId = None
         self.Role = None
         self.GameContext = None
+        self.RunMode = None
 
 
     def _deserialize(self, params):
@@ -97,6 +102,7 @@ class CreateSessionRequest(AbstractModel):
         self.HostUserId = params.get("HostUserId")
         self.Role = params.get("Role")
         self.GameContext = params.get("GameContext")
+        self.RunMode = params.get("RunMode")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -233,6 +239,51 @@ class SaveGameArchiveResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class StartPublishStreamRequest(AbstractModel):
+    """StartPublishStream请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param UserId: 唯一用户身份标识，由业务方自定义，平台不予理解。（可根据业务需要决定使用用户的唯一身份标识或是使用时间戳随机生成；在用户重连时应保持UserId不变）
+        :type UserId: str
+        :param PublishUrl: 推流地址，仅支持rtmp协议
+        :type PublishUrl: str
+        """
+        self.UserId = None
+        self.PublishUrl = None
+
+
+    def _deserialize(self, params):
+        self.UserId = params.get("UserId")
+        self.PublishUrl = params.get("PublishUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class StartPublishStreamResponse(AbstractModel):
+    """StartPublishStream返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class StopGameRequest(AbstractModel):
     """StopGame请求参数结构体
 
@@ -278,6 +329,47 @@ class StopGameResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class StopPublishStreamRequest(AbstractModel):
+    """StopPublishStream请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param UserId: 唯一用户身份标识，由业务方自定义，平台不予理解。（可根据业务需要决定使用用户的唯一身份标识或是使用时间戳随机生成；在用户重连时应保持UserId不变）
+        :type UserId: str
+        """
+        self.UserId = None
+
+
+    def _deserialize(self, params):
+        self.UserId = params.get("UserId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class StopPublishStreamResponse(AbstractModel):
+    """StopPublishStream返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class SwitchGameArchiveRequest(AbstractModel):
     """SwitchGameArchive请求参数结构体
 
